import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: root

    property string filePath: ""
    property string folder

    property Style platformStyle: FileBrowserStyle {}

    property string __iconStyle: platformStyle.inverted ? "-white" : ""

    Component.onCompleted: {
        fileSystemModel.slotLoadDirectory("/home/user/MyDocs")
    }

    Item {
        id: toolBar
        anchors.top: parent.top
        anchors.topMargin: 10
        anchors.left: parent.left
        anchors.right: parent.right
        height: backButton.height

        Button {
            id: backButton
            anchors.left: parent.left
            width: 160
            platformStyle: ButtonStyle {inverted: root.platformStyle.inverted }
            text: qsTr("Up")
            iconSource: "image://theme/icon-m-toolbar-previous" + __iconStyle
            onClicked: fileSystemModel.slotOpenSubDir("..")
            opacity: 1
        }

        Label {
            id: toolBarLabel
            platformStyle: LabelStyle { inverted: root.platformStyle.inverted }
            anchors.left: backButton.right
            anchors.leftMargin: 6
            anchors.right: parent.right
            height: backButton.height
            elide: Text.ElideLeft
            verticalAlignment: Text.AlignVCenter

            Connections {
                target: fileSystemModel

                onCurrentDirectoryChanged: {
                    toolBarLabel.text = newDir
                    backButton.opacity = (newDir !== "/" ? 1.0 : 0.5)
                }
            }
        }
    }

    ScrollDecorator { flickableItem: folderBrowserListView }

    ListView {
        id: folderBrowserListView

        anchors {
            top: toolBar.bottom
            topMargin: 10
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }

        clip: true

        model: fileSystemModel
        delegate: fileDelegate

        Component {
            id: fileDelegate
            Rectangle {
                color: itemMouseArea.pressed ?
                    root.platformStyle.itemSelectedBackgroundColor :
                    root.platformStyle.itemBackgroundColor

                width: parent.width
                height: root.platformStyle.itemHeight

                Image {
                    anchors.verticalCenter: parent.verticalCenter
                    height: parent.height
                    width: height
                    source: model.isFolder? "image://theme/icon-m-toolbar-directory" + __iconStyle : "image://theme/icon-m-toolbar-done-selected" // + __iconStyle
                }

                Text {
                    text: model.displayName

                    font: root.platformStyle.itemFont
                    color: root.platformStyle.itemTextColor
                    anchors.fill: parent
                    anchors.leftMargin: parent.height
                    verticalAlignment: Text.AlignVCenter
                }

                MouseArea {
                    id: itemMouseArea
                    anchors.fill: parent
                    onClicked: {
                        if (model.isFolder) {
                            fileSystemModel.slotOpenSubDir(model.displayName)
                        } else {
                            root.filePath = model.displayName
                        }
                    }
                }
            }
        }
    }
}
