// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "JsModule.js" as JS

Page {

    id: rootPage

    property bool isCopyOrMoveRunning: false
    property bool isCurOperIsCopy: false
    property string fileToMoveOrCopy: ""

    //property bool isGridMode: true

    property variant selectedItem: null

    anchors.fill: parent
    orientationLock: PageOrientation.LockPortrait

    Component.onCompleted: {
        viewChanged()
        tools = commonTools
    }

    function showDeleteDialog(fileName) {

        deleteFileSubmission.titleText = fileName
        if (selectedItem.isFolder) {
            deleteFileSubmission.icon = "qrc:/img/folder.png"
            deleteFileSubmission.message = qsTr("Really want to delete folder?")
        }
        else {
            deleteFileSubmission.icon = JS.getImageByFileType(fileName)
            deleteFileSubmission.message = qsTr("Really want to delete file?")
        }

        deleteFileSubmission.open();
    }

    function showTransferDialog(name, isDownload) {
        var slInd = name.lastIndexOf("/")
        if (slInd !== -1)
        {
            name = name.substr(slInd + 1)
        }

        transferDialog.fileName = name
        transferDialog.isDownlaod = isDownload
        transferDialog.startDialog()
    }

    function stopTransferDialog() {
        transferDialog.stopDialog()
    }

    function showNewFolderDialog() {
        renameInputDialog.isForRename = false
        renameInputDialog.value = ""
        renameInputDialog.open()
    }

    function ensureTransferDialogClosed() {
        if (transferDialog.status !== DialogStatus.Closed)
            stopTransferDialog();
    }

    function viewChanged() {
        var v = optKeeper.useGridView
        listView.visible = !v
        listView.model = (!v)? folderModel : undefined
        gridView.visible = v
        gridView.model = (v)? folderModel : undefined
        scrollDecor.flickableItem = v? gridView : listView
    }

    function showErrorMessage(text) {
        infoBanner.text = text
        infoBanner.iconSource = "qrc:/img/fail.png"
        infoBanner.show()
    }

    ToolBarLayout {
        id: commonTools
        visible: true

        ToolIcon {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (myMenu.status === DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }

        ToolIcon {
            property bool isActive: bridge.currentFolder != "/"
            iconSource: isActive? "qrc:/img/back.png" : "qrc:/img/back_des.png"
            anchors.left: (parent === undefined) ? undefined : parent.left
            enabled:  isActive
            onClicked: {
                bridge.slotOneLevelBack()
            }
        }

        ToolIcon {
            id: refreshIcon
            property bool modeIsRefresh: true
            iconSource: modeIsRefresh? "qrc:/img/refresh.png" : "qrc:/img/cancel.png"
            anchors.centerIn: (parent === undefined) ? undefined : parent
            onClicked: {
                if (modeIsRefresh)
                    bridge.slotUpdate()
                else bridge.slotAbort()
            }

            Connections {
                target: bridge

                onIsBusyChanged: {
                    var val = bridge.isBusy
                    refreshIcon.modeIsRefresh = !val
                }
            }
        }
    }

    ToolBarLayout {
        id: copyPasteTools

        visible: false

        ToolIcon {
            property bool isActive: bridge.currentFolder != "/"
            iconSource: isActive? "qrc:/img/back.png" : "qrc:/img/back_des.png"
            anchors.left: (parent === undefined) ? undefined : parent.left
            enabled:  isActive
            onClicked: {
                bridge.slotOneLevelBack()
            }
        }

        Rectangle {

            id: clipRect

            color: "#00ff0000"
            width: 300
            height: 50
            clip: true

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter

            ButtonRow {

                width: parent.width

                style: ButtonStyle {
                    property string __colorString: "color" + 10 + "-"
                }

                Button {
                    id: btnCanc
                    text: qsTr("Cancel");
                    width: 150

                    onClicked: {
                        isCopyOrMoveRunning = false;
                        appWindow.pageStack.toolBar.setTools(commonTools)
                    }
                }

                Button {
                    id: btnSelect
                    text: qsTr("Select");
                    width: 150

                    onClicked: {
                        isCopyOrMoveRunning = false;
                        appWindow.pageStack.toolBar.setTools(commonTools)

                        var curFolder = bridge.currentFolder
                        if (!JS.endsWith(curFolder, "/"))
                            curFolder += "/"

                        var path = rootPage.fileToMoveOrCopy
                        var ind = path.lastIndexOf("/") + 1
                        var shortFn = path.substr(ind)

                        if (shortFn == "") { // Work with folder
                            ind = path.lastIndexOf("/", path.length - 2) + 1 // -2 to miss last '/' at the end.
                            shortFn = path.substr(ind)
                        }

                        var newName = curFolder + shortFn
                        if (folderView.isCurOperIsCopy)
                            bridge.slotCopyFile(path, newName)
                        else {
                            bridge.slotRenameFile(path, newName)
                            fileToMoveOrCopy = ""
                        }

//                        var curFolder = bridge.currentFolder
//                        if (!JS.endsWith(curFolder, "/"))
//                            curFolder += "/"
//                        var ind = rootPage.fileToMoveOrCopy.lastIndexOf("/") + 1
//                        var shortFn = rootPage.fileToMoveOrCopy.substr(ind)
//                        var newName = curFolder + shortFn;
//                        if (rootPage.isCurOperIsCopy)
//                            bridge.slotCopyFile(rootPage.fileToMoveOrCopy, newName)
//                        else bridge.slotRenameFile(rootPage.fileToMoveOrCopy, newName)
                    }
                }
            }
        }
    } // copyPasteTools


    TitleBar {
        id: titleBar

        anchors.top: parent.top
    }

    InputDialog {
        id: renameInputDialog

        onAccepted: {
            var curDir = bridge.currentFolder;
            if (!JS.endsWith(curDir, "/"))
                curDir += "/";
            if (isForRename)
                bridge.slotRenameFile(curDir + selectedItem.displayName,
                                      curDir + renameInputDialog.value)
            else bridge.slotCreateFolder(curDir + renameInputDialog.value)
        }
    }

    QueryDialog {
        id: deleteFileSubmission
        message: qsTr("Really want to delete file?")
        acceptButtonText: qsTr("Yes")
        rejectButtonText: qsTr("No")
        onAccepted: {
            bridge.slotDeleteFile(selectedItem.href)
        }
    }

    QueryDialog {
        id: dlgFileDownloaded
        property string sUrl: ""

        titleText: qsTr("File downloaded")
        message: qsTr("Open downloaded file with the default program?")
        acceptButtonText: qsTr("Yes")
        rejectButtonText: qsTr("No")
        onAccepted: {
            bridge.slotOpenUrl(sUrl)
        }
    }

    QueryDialog {
        id: diskSpaceInfoDialog
        titleText: qsTr("Disk information")
        icon: "qrc:/img/logo_black.png"
        acceptButtonText: qsTr("Ok")
    }

    TransferDialog {
        id: transferDialog
    }

    FolderViewContextMenu {
        id: cntxMenuFile
    }

    // --------------------------------------------- TEMP

    QtObject {
        id: groupOperationHandler

        property string operation: "none"
        property bool isRunning: false
        property variant fileList: null
        property int currentIndex: 0

        signal operationCompleted()
        signal workDone()

        function startGroupOperation(oper) {
            isRunning = true
            operation = oper
            currentIndex = 0
            bridge.autoUpdate = false
            var files = []

            for (var i = 0; i < folderModel.entryCount; i++) {
                if (folderModel.itemIsSelected(i)) {
                    var href = folderModel.itemHref(i)
                    files.push(href)
                }
            }

            fileList = files

            groupDialog.startDialog(files.length)

            performOperation()
        }

        function performOperation() {
            switch(operation)
            {
            case "delete":
                bridge.slotDeleteFile(fileList[currentIndex])
                break
            case "download":
                console.log("TODO")
                break
            }
        }

        function processJobDone(code, result) {

            groupDialog.increaseProgress()

            currentIndex++;
            if (currentIndex >= fileList.length) {
                groupOperationHandler.isRunning = false
                bridge.autoUpdate = true
                groupDialog.finishWithSuccess()
                delayedUpdateTimer.start()
            }
            else performOperation()
        }
    }

    GroupOperationDialog {
        id: groupDialog

        onCancelClicked: {
            groupOperationHandler.isRunning = false
            bridge.autoUpdate = true
            stopDialog()
            delayedUpdateTimer.start()
        }
    }

    Timer {
        id: delayedUpdateTimer
        interval: 400
        onTriggered: {
            bridge.slotUpdate()
        }
    }

    // --------------------------------------------- TEMP

    InfoBanner {
        id: infoBanner
        property int __btmOffset: 10
        z: 19
        topMargin: parent.height - __btmOffset - height
        timerShowTime: 3500
    }

    Connections {
        target: bridge

        onJobDone: {

            if (resCode !== 7)
                console.log("JS SAYS STATUS: " + resCode + " MESSAGE: " + sResult)
            else console.log("JS SAYS STATUS: ", resCode)

            if (groupOperationHandler.isRunning) {
                groupOperationHandler.processJobDone(resCode, sResult)
                return
            }

            infoBanner.iconSource = "qrc:/img/success.png"

            switch(resCode)
            {
            case -1:
            {
                infoBanner.text = qsTr("Error: ") + sResult
                infoBanner.iconSource = "qrc:/img/fail.png"
                infoBanner.show()
                ensureTransferDialogClosed()
            }
            break;
            case 0:

                break;
            case 1:
            {
                infoBanner.text = sResult
                infoBanner.show()
            }
            break;
            case 2:
            {
                ensureTransferDialogClosed()
                var sFilePath = sResult.substr(sResult.indexOf(":") + 2)
                dlgFileDownloaded.icon = JS.getImageByFileType(sFilePath)
                dlgFileDownloaded.sUrl = sFilePath
                dlgFileDownloaded.open();
            }
            break;
            case 3:
            {
                infoBanner.text = sResult
                infoBanner.show()
            }
            break;
            case 4:
            {
                infoBanner.text = sResult
                infoBanner.show()
            }
            break;
            case 5:
            {
                infoBanner.text = sResult
                infoBanner.show()
            }
            break;
            case 6:
            {
                var infoParts = sResult.split(';')
                if (infoParts.length == 2)
                {
                    var msg = qsTr("Available space: ") +
                            JS.decorateFileSize(parseInt(infoParts[0])) +
                            "\n" + qsTr("Used space: ") +
                            JS.decorateFileSize(parseInt(infoParts[1]))

                    diskSpaceInfoDialog.message = msg
                    diskSpaceInfoDialog.open()
                }

            }
            break;
            }
        }
    }

    ListView {
        id: listView

        anchors {
            top: titleBar.bottom
            bottom: parent.bottom
        }
        width: parent.width;

        model: folderModel

        highlight: Rectangle {
            color: "lightsteelblue";
            width: listView.width
        }
        highlightMoveSpeed: 600
        focus: true

        delegate: FolderViewDelegate {}
    }

    GridView {
        id: gridView

        property variant modelItem: null

        anchors {
            top: titleBar.bottom
            topMargin: 5
            bottom: parent.bottom
        }
        width: parent.width;
        cellWidth: 120; cellHeight: 145

        highlight: Rectangle {
            color: "lightsteelblue";
            width: listView.width
        }

        model: folderModel
        focus: true
        delegate: FolderViewGridDelegate {}

        onCurrentIndexChanged: {
            if (currentIndex == -1 || modelItem == null || modelItem.isFolder)
            {
                fileInfoItem.opacity = 0
                return
            }

            fileInfoItem.showData(JS.decorateFileSize(modelItem.contLen) +
                                  (optKeeper.showFileTime? ("   " + modelItem.lastModif) : ""))
        }

        Rectangle {
            id: fileInfoItem

            property alias text: fileInfoItemText.text

            function showData(data) {
                if (!optKeeper.showFileTime)
                    return
                opacity = 1
                text = data
                hideTimer.restart()
            }

            color: "darkgray"
            width: fileInfoItemText.width
            height: fileInfoItemText.height
            opacity: 0

            anchors {
                bottom: parent.bottom
                bottomMargin: 10
                horizontalCenter: parent.horizontalCenter
            }

            Label {
                id: fileInfoItemText

                width: 360
                font.pointSize: 6
                anchors.centerIn: parent
                wrapMode: Text.WordWrap
                horizontalAlignment: Text.AlignHCenter
                color: "white"
            }

            Timer {
                id: hideTimer
                interval: 4000
                onTriggered: {
                    fileInfoItem.opacity = 0
                    gridView.modelItem = null
                }
            }

            Behavior on opacity {
                NumberAnimation { duration: 500 }
            }
        }
    }

    Connections {
        target: optKeeper

        onUseGridViewChanged: {
            viewChanged()
        }
    }

    Label {
        z: 5
        visible: folderModel.entryCount === 0
        anchors.centerIn: parent
        text: qsTr("Empty folder")
        color: "#CCCCCC"
        font.pixelSize: 60
        font.italic: true
    }

    ScrollDecorator {
        id: scrollDecor
    }
}
