import QtQuick 1.1
import com.nokia.meego 1.0

import "JsModule.js" as JS

Item {
    id: rootDelRect

    property int iconSize: 48

    height: 64
    width: listView.width

    function decorateLastModif(lastMod) {
        // lastMod = lastMod.replace(" GMT", "") todo GMT
        return "   " + lastMod;
    }

    Image {
        id: fileIcon
        source: model.isFolder? "qrc:/img/folder.png" : JS.getImageByFileType(model.displayName)

        asynchronous: true

        sourceSize.width: iconSize
        sourceSize.height: iconSize

        anchors.left: parent.left
        anchors.leftMargin: 10
        anchors.verticalCenter: parent.verticalCenter
    }

    Label {

        id: textFileName
        color: model.isSelected? "#7517e4" : "black"
        elide: Text.ElideRight
        width: ( index === listView.currentIndex)? parent.width - 170 : parent.width - 65

        Component.onCompleted: {
            if (model.isFolder) {
                anchors.verticalCenter = parent.verticalCenter
            } else {
                anchors.top = parent.top
                anchors.topMargin = 5
            }
        }

        text: model.displayName
        anchors.left: fileIcon.right
        anchors.leftMargin: 4

        font.pointSize: 20
    }

    Image {
        id: btnMenu

        opacity: (!model.isFolder && index === listView.currentIndex)? 1 : 0
        source: "qrc:/img/std_menu.png"
        z: 2

        sourceSize.width: iconSize
        sourceSize.height: iconSize

        anchors.right: parent.right
        anchors.rightMargin: 5
        anchors.verticalCenter: parent.verticalCenter

        MouseArea {
            anchors.fill: parent
            onClicked: {
                listView.currentIndex = index;

                if (folderView.isCopyOrMoveRunning)
                    return;

                selectedItem = model
                cntxMenuFile.open()
            }
        }

        Behavior on opacity {
            NumberAnimation { duration: 500 } // todo easing.type: Easing.InQuad;
        }
    }

    Image {
        id: btnDownload

        opacity: (!model.isFolder && index === listView.currentIndex)? 1 : 0
        source: "qrc:/img/std_download.png"
        z: 2

        sourceSize.width: iconSize
        sourceSize.height: iconSize

        anchors.right: btnMenu.left
        anchors.rightMargin: 5
        anchors.verticalCenter: parent.verticalCenter

        MouseArea {
            anchors.fill: parent
            onClicked: {
                listView.currentIndex = index;

                if (folderView.isCopyOrMoveRunning)
                    return;

                selectedItem = model

                if (selectedItem.isFolder)
                {
                    infoBanner.text = qsTr("Can't download folder!")
                    infoBanner.iconSource = "qrc:/img/fail.png"
                    infoBanner.show()
                    return
                }

                var freeSpace = bridge.slotGetFreeSpace()
                if (freeSpace < selectedItem.contLen)
                {
                    infoBanner.text = qsTr("Not enought free space!")
                    infoBanner.iconSource = "qrc:/img/fail.png"
                    infoBanner.show()
                    return
                }

                folderView.showTransferDialog(selectedItem.displayName, true) // isDownload, true
                bridge.slotDownloadFile(selectedItem.href);
            }
        }

        Behavior on opacity {
            NumberAnimation { duration: 500; }
        }
    }

    Text { // todo label

        id: textFileSize
        text: JS.decorateFileSize(model.contLen) + (optKeeper.showFileTime? decorateLastModif(model.lastModif) : "")
        visible: !model.isFolder
        color: "#7517e4"

        anchors.left: fileIcon.right
        anchors.leftMargin: 4
        anchors.top: textFileName.bottom
        anchors.topMargin: -2

        font.pointSize: 12
    }

    MouseArea {
        anchors.fill: parent

        onPressed: {
            listView.currentIndex = index;
        }

        onClicked: {
            if (isFolder)
                bridge.slotMoveToFolder(model.displayName)
        }

        onDoubleClicked: {
            folderModel.toggleIsSelected(model.index);
        }

        onPressAndHold: {
            if (folderView.isCopyOrMoveRunning)
                return;

            selectedItem = model
            cntxMenuFile.open()
        }
    }
}
