// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

Page {
    id: pageRoot


    property bool isBusy: false
    property alias strLogin: tfLogin.text
    property alias strPass: tfPass.text
    property alias isAuto: chbAuto.checked

    signal authPassed

    orientationLock: PageOrientation.LockPortrait

    function resetValues() {
        strLogin = ""
        strPass = ""
        isAuto = false
    }

    Rectangle {
        id: backgrRect
        color: "#eeeeee"
        anchors.fill: parent


        Item {
            id: contentRect
            width: 350
            height: 350

            anchors.centerIn: parent

            Column {
                spacing: 5

                Label {
                    text: qsTr("Login")
                    anchors.left: parent.left
                    anchors.leftMargin: 10
                    color: "#7517e4"
                }

                TextField {
                    id: tfLogin
                    width: 350
                    anchors.horizontalCenter: parent.horizontalCenter
                }

                Label {
                    text: qsTr("Password")
                    anchors.left: parent.left
                    anchors.leftMargin: 10
                    color: "#7517e4" // pretty cool
                }

                TextField {
                    id: tfPass
                    width: 350
                    echoMode: TextInput.Password
                    anchors.horizontalCenter: parent.horizontalCenter
                }

                Item {
                    id: btnsItem
                    width: 350
                    height: 130

                    anchors.topMargin: 10
                    anchors.horizontalCenter: parent.horizontalCenter

                    CheckBox {
                        id: chbAuto
                        text: qsTr("Remember")

                        anchors.left: parent.left
                        anchors.top: parent.top
                        anchors.topMargin: 5
                        anchors.leftMargin: 10

                        Component.onCompleted: {
                            platformStyle.__colorString = "color" + 10 + "-"
                        }
                    }

                    BusyIndicator {
                        id: busyInd

                        anchors.right: parent.right
                        anchors.top: parent.top
                        anchors.topMargin: 12
                        anchors.rightMargin: 15

                        running: isBusy
                        visible: isBusy

                        platformStyle: BusyIndicatorStyle {
                            size: "medium"
                        }
                    }

                    Button {
                        id: btnOk
                        width: 150

                        text: isBusy ? qsTr("Cancel") : qsTr("Enter")
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.bottom: parent.bottom

                        onClicked: {
                            if (isBusy)
                            {
                                authChecker.slotAbortOperation()
                                return
                            }

                            isBusy = true
                            authChecker.slotCheck(tfLogin.text, tfPass.text)
                        }

                        platformStyle: ButtonStyle {
                            property string __colorString: "color" + 10 + "-"
                        }
                    }
                }
            }
        }
    }

    InfoBanner {
        id: logFailure

        property bool netError: false
        z: 50
        topMargin: 300
        timerShowTime: 2500
        text: netError? qsTr("Network error!") : qsTr("Login or password is incorrect!")
        iconSource: "qrc:/img/fail.png"
    }

    QueryDialog {
        id: privPolDlg

        message: qsTr("The application uses your personal information for access to the service. We guarantee that they will not be used for other purposes.")
        titleText: qsTr("Privacy Policy")
        icon: "qrc:/img/logo_black.png"
        acceptButtonText: qsTr("Ok")
    }

    QueryDialog {
        id: forbDialog

        message: qsTr("To use the service, you need an invitation. You can get it for free, but only with the help of a personal computer. Simply select the \"Disk\" in the mail, and then follow the instructions.")
        titleText: qsTr("Access forbidden")
        icon: "qrc:/img/logo_black.png"
        acceptButtonText: qsTr("Ok")
    }

    Label {
        id: privPolicy
        text: qsTr("Privacy Policy")

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 5
        anchors.left: parent.left
        anchors.leftMargin: 15
        font.underline: true

        MouseArea {
            anchors.fill: parent

            onClicked: {
                privPolDlg.open()
            }
        }
    }

    Label {
        id: registerLabel
        text: qsTr("Register...")
        color: linkMa.pressed? "black" : "#7517e4"

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 5
        anchors.right: parent.right
        anchors.rightMargin: 15
        font.underline: true

        MouseArea {
            id: linkMa
            anchors.fill: parent

            onClicked: {
                Qt.openUrlExternally("http://mail.yandex.ru/")
            }
        }
    }

    Connections {
        target: authChecker

        onCheckFinished: {
            isBusy = false

            if (checkStatus === 2) // User pushed 'Cancel" - do nothing.
                return

            if (checkStatus === -2) { // Access forbidden by server.
                forbDialog.open()
                return
            }

            if (checkStatus === 0) // Successful login.
            {
                bridge.slotStoreValues(tfLogin.text, tfPass.text, chbAuto.checked)
                authPassed()
            } else {
                if (checkStatus === -1)
                    logFailure.netError = false
                else logFailure.netError = true

                logFailure.show()
            }

        }
    }
}
