import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

Page {
    id: pageRoot

    signal closeRequest

    property bool preventSave: false

    orientationLock: PageOrientation.LockPortrait
    tools: optionsTools

    function updateInfoFromOptions() {
        pageRoot.preventSave = true

        chbDefDir.checked = optKeeper.useDefaultDir
        chbShowFileTime.checked = optKeeper.showFileTime
        tfAltDir.text = optKeeper.alternateDirectory
        swUseGridView.checked = optKeeper.useGridView

        pageRoot.preventSave = false
    }

    SimpleTitleBar {
        id: optionsTitleBar
        text: qsTr("Options")
    }

    Rectangle {
        id: mainOptionsArea

        color: "#00ffeeee"

        anchors.top: optionsTitleBar.bottom
        anchors.bottom: parent.bottom
        width: parent.width

        Column {
            id: optionsList
            width: parent.width

            property int sideMargin: 10
            property int lineOffset: 50

            spacing: 20

            // Default dir option.
            Rectangle {
                id: defDirOption
                width: parent.width
                height: 110
                anchors.horizontalCenter: parent.horizontalCenter
                color: "transparent"

                Label {
                    id: lblDefDirUsed
                    text: qsTr("Use default directory")
                    color: "#7517e4" // pretty cool

                    anchors.left: parent.left
                    anchors.leftMargin: optionsList.sideMargin * 2
                    anchors.verticalCenter: chbDefDir.verticalCenter
                }

                CheckBox {
                    id: chbDefDir

                    anchors.right: parent.right
                    anchors.rightMargin: optionsList.sideMargin
                    anchors.top: parent.top
                    anchors.topMargin: optionsList.sideMargin

                    Component.onCompleted: {
                        platformStyle.__colorString = "color" + 10 + "-"
                    }

                    onCheckedChanged: {
                        if (pageRoot.preventSave)
                            return

                        optKeeper.useDefaultDir = checked
                    }
                }

                TextField {
                    id: tfAltDir

                    readOnly: chbDefDir.checked
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: parent.width - optionsList.lineOffset
                    anchors.bottom: parent.bottom

                    onTextChanged: {
                        optKeeper.alternateDirectory = text
                    }

                }
            }

            Rectangle {
                color: "lightgray"
                width: parent.width - optionsList.lineOffset
                height: 2
                anchors.horizontalCenter: parent.horizontalCenter
            }

            // Show file time option.
            Rectangle {
                id: showFileTimeOption
                width: parent.width
                height: 40
                anchors.horizontalCenter: parent.horizontalCenter
                color: "transparent"

                Label {
                    id: lblShowFileTime
                    text: qsTr("Show file time")
                    color: "#7517e4"

                    anchors.left: parent.left
                    anchors.leftMargin: optionsList.sideMargin * 2
                    anchors.verticalCenter: parent.verticalCenter
                }

                Switch {
                    id: chbShowFileTime

                    anchors.right: parent.right
                    anchors.rightMargin: optionsList.sideMargin
                    anchors.verticalCenter: parent.verticalCenter

                    Component.onCompleted: {
                        platformStyle.__colorString = "color" + 10 + "-"
                    }

                    onCheckedChanged: {
                        if (pageRoot.preventSave)
                            return

                        optKeeper.showFileTime = checked
                    }
                }
            }

            Rectangle {
                color: "lightgray"
                width: parent.width - optionsList.lineOffset
                height: 2
                anchors.horizontalCenter: parent.horizontalCenter
            }

            // Use grid view option.
            Rectangle {
                id: useGridViewOption
                width: parent.width
                height: 40
                anchors.horizontalCenter: parent.horizontalCenter
                color: "transparent"

                Label {
                    id: lblUseGridView
                    text: qsTr("Use grid view")
                    color: "#7517e4"

                    anchors.left: parent.left
                    anchors.leftMargin: optionsList.sideMargin * 2
                    anchors.verticalCenter: parent.verticalCenter
                }

                Switch {
                    id: swUseGridView

                    anchors.right: parent.right
                    anchors.rightMargin: optionsList.sideMargin
                    anchors.verticalCenter: parent.verticalCenter

                    Component.onCompleted: {
                        platformStyle.__colorString = "color" + 10 + "-"
                    }

                    onCheckedChanged: {
                        if (pageRoot.preventSave)
                            return

                        optKeeper.useGridView = checked
                    }
                }
            }

            Rectangle {
                color: "lightgray"
                width: parent.width - optionsList.lineOffset
                height: 2
                anchors.horizontalCenter: parent.horizontalCenter
            }

        }
    }

    ToolBarLayout {
        id: optionsTools
        visible: true

        ToolIcon {
            platformIconId: "toolbar-back"
            anchors.left: (parent === undefined) ? undefined : parent.left

            onClicked: {
                closeRequest()
            }
        }
    }
}
