import QtQuick 1.1
import com.nokia.meego 1.0

PageStackWindow {
    id: appWindow

    property variant fileChooseDialog: null

    width: 480
    height: 854
    z: 15

    initialPage: bridge.slotCheckAutoLogin()? folderView : loginPage

    function openDialogByType(type) {

        if (type === 0) {
            photoPickPage.loadGalleryModel()
            pageStack.push(photoPickPage)
        } else {
            if (fileChooseDialog == null) {
                var component = Qt.createComponent("FileDialogDialog.qml");
                if (component.status == Component.Ready) {
                    fileChooseDialog = component.createObject(folderView);
                    fileChooseDialog.folder = bridge.slotGetDefBrowseLocation()
                    fileChooseDialog.selectExisting = true
                    fileChooseDialog.accepted.connect(fileDialogAccepted)
                    fileChooseDialog.titleText = qsTr("Select file")
                }
            }

            fileChooseDialog.open()
        }
    }

    function imageUploadDialogAccepted(sUrl) {
        var fullPath = sUrl
        folderView.showTransferDialog(fullPath, false)
        var res = bridge.slotUploadFile(fullPath);
        if (!res)
        {
            folderView.showErrorMessage(qsTr("Error! Can't transfer file!"))
            folderView.stopTransferDialog()
        }
    }

    function fileDialogAccepted() {

        var fullPath = fileSystemModel.slotCurrentDirectory() + "/" + fileChooseDialog.filePath
        folderView.showTransferDialog(fullPath, false)
        var res = bridge.slotUploadFile(fullPath);
        if (!res)
        {
            folderView.showErrorMessage(qsTr("Error! Can't transfer file!"))
            folderView.stopTransferDialog()
        }
    }

    function someLoaderFinished() {
        console.log("SomeLoaderFinished")
    }

    LoginPage {
        id: loginPage

        onAuthPassed: {
            bridge.slotMoveToFolder("/")
            appWindow.pageStack.pop(loginPage)
            appWindow.pageStack.push(folderView)
        }
    }

    FolderView {
        id: folderView
    }

    PhotoPickPage {
        id: photoPickPage

        Component.onCompleted: {
            photoPickPage.imageSelected.connect(imageUploadDialogAccepted)
        }
    }

    OptionsPage {
        id: optionsPage

        onCloseRequest: {
            appWindow.pageStack.pop(optionsPage)
        }
    }


    QueryDialog {
        id: signOutSubmission
        message: qsTr("Are you really want sign out?")
        titleText: qsTr("Sign out")
        acceptButtonText: qsTr("Yes")
        rejectButtonText: qsTr("No")
        icon: "qrc:/img/logo_black.png"
        onAccepted: {
            bridge.slotResetAuth()
            loginPage.resetValues()
            appWindow.pageStack.pop(folderView)
            appWindow.pageStack.push(loginPage)
        }
    }

    SelectionDialog {
        id: uploadTypeSelection
        titleText: qsTr("Select upload file type")
        selectedIndex: -1

        ListModel {
            id: uploadTypeSelectionModel
            ListElement { name: "Image" }
            ListElement { name: "Any" }

            Component.onCompleted: {
                uploadTypeSelectionModel.get(0).name = qsTr("Image")
                uploadTypeSelectionModel.get(1).name = qsTr("Any file")

                uploadTypeSelection.model = uploadTypeSelectionModel
            }
        }

        onAccepted: {
            openDialogByType(selectedIndex)
        }
    }

    FolderViewMainMenu {
        id: myMenu
        visualParent: pageStack
    } // menu

    QueryDialog {
        id: dialogAbout

        message: qsTr("Unofficial <font color='#7517e4'>MeeGo</font> client for <a href='http://disk.yandex.com/'>Yandex.Disk</a> free file storage service<br> Developed by Roman Shchekin <br> aka <font color='#7517e4'>QtRoS</font><br>QtRoS@yandex.ru") + "<br>v2.0.0-1"
        titleText: qsTr("<font color='#7517e4'>YaD</font>")
        icon: "qrc:/img/logo_black.png"
        acceptButtonText: qsTr("Ok")

        onLinkActivated: {
            Qt.openUrlExternally(link)
        }
    }
}
