import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: photoPickerPage

    property variant galleryModel;
    property bool __isModelLoaded: false

    signal imageSelected(string sUrl)

    function loadGalleryModel() {
        if (__isModelLoaded)
            return
        var component = Qt.createComponent("PhotoPickGalleryModel.qml");
        if (component.status === Component.Ready){
            galleryModel = component.createObject(photoPickerPage);
            __isModelLoaded = true;
        } else {
            galleryModel = null;
        }
    }

    orientationLock: PageOrientation.LockPortrait
    anchors.fill: parent

    tools: ToolBar {
        id: pickerTb

        ToolItem {
            iconId: "icon-m-toolbar-back";
            onClicked: {
                appWindow.pageStack.pop()
            }
        }
    }

    SimpleTitleBar {
        id: photoPrevTitleBar
        text: qsTr("Select photo")
    }

    GridView {
        id: picturesGrid

        anchors {
            top: photoPrevTitleBar.bottom
            bottom: parent.bottom

        }
        width: (Screen.currentOrientation === Screen.Landscape)? (parent.width - 14) : parent.width

        property int cellSz : 160
        cellWidth: 160
        cellHeight: 160

        model: photoPickerPage.galleryModel

        delegate: Rectangle {
            id: photosDelegate

            width: 160
            height: 160

            color: "#fafafa"

            Image {
                id: photo

                property bool isEncodedUrl: false

                anchors.fill: parent
                asynchronous: true
                opacity: 1

                fillMode: Image.PreserveAspectCrop
                clip: true
                sourceSize.width: 240 // mb height
                source: model.url

                onStatusChanged: {
                    // Trying to fix problem with bad encoding...
                    if (status === Image.Error) {
                        if (isEncodedUrl)
                            return

                        isEncodedUrl = true
                        source = bridge.slotFromPercentEncoding(model.url)
                    }
                }

                MouseArea{
                    anchors.fill: parent;
                    onClicked: {
                        imageSelected(photo.source)
                        pageStack.pop()
                    }
                }
            }

//            states:[
//                State{
//                    name: "Show";
//                    when: photo.status == Image.Ready;
//                    PropertyChanges {
//                        target: photo;
//                        opacity: 1;
//                    }
//                }
//            ]
        }
    }

    ScrollDecorator { flickableItem: picturesGrid }
}
