import QtQuick 1.1
import com.nokia.meego 1.0
import "JsModule.js" as JS

Dialog {
    id: rootDialog

    property bool isDownlaod: true
    property bool finished: false
    property alias fileName: fileNameLabel.text
    property real totalLen: 1

    title: Label {
        id: titleLabel

        text: isDownlaod? qsTr("Downloading") : qsTr("Uploading")
        color: "#7517e4"
        font.pixelSize: 36

        anchors.horizontalCenter: parent.horizontalCenter

    }

    onStatusChanged: {
        if (status === DialogStatus.Closing && !finished)
            status = 1
    }

    function stopDialog() {

        bridge.slotAbort();

        if (isDownlaod) {
            bridge.downloadProgress.disconnect(progressChanged)
        } else {
            bridge.uploadProgress.disconnect(progressChanged)
        }

        finished = true;
        status = DialogStatus.Closed
    }

    function finishWithSuccess() {

        if (isDownlaod) {
            bridge.downloadProgress.disconnect(progressChanged)
        } else {
            bridge.uploadProgress.disconnect(progressChanged)
        }

        finished = true;
        status = DialogStatus.Closed
    }

    function startDialog() {
        finished = false
        progressBar.value = 0

        if (isDownlaod) {
            bridge.downloadProgress.connect(progressChanged)
        } else {
            bridge.uploadProgress.connect(progressChanged)
        }

        rootDialog.open()
    }

    function progressChanged(current, total) {
        if (total !== totalLen)
        {
            totalLen = total
            progressBar.maximumValue = total

            if (total === -1)
                progressBar.indeterminate = true
            else progressBar.indeterminate = false
        }

        progressBar.value = current

        if (current === total) // todo think mb need >=
            finishWithSuccess()
    }


    content: Rectangle {
        color: "#00000000"
        height: 80 + fileNameLabel.height
        width: parent.width

        Label {
            id: fileNameLabel

            text: "file.txt"
            color: "white"
            font.pixelSize: 26
            width: parent.width
            horizontalAlignment: Text.AlignHCenter

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 20
        }

        ProgressBar {
            id: progressBar

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20

            width: 300
            minimumValue: 0
            value: 0

            Component.onCompleted: {
                platformStyle.__colorString = "color" + 10 + "-"
            }
        }
    }


    buttons: Rectangle {
        color: "#00000000"
        height: 75
        width: parent.width

        Button {

            width: 150
            anchors.centerIn: parent
            text: qsTr("Cancel");
            onClicked: transferDialog.stopDialog()

            platformStyle: ButtonStyle {
                property string __colorString: "color" + 10 + "-"
            }
        }
    }
}
